OC.L10N.register(
    "spreed",
    {
    "a conversation" : "pokalbis",
    "(Duration %s)" : "(Trukmė %s)",
    "You attended a call with {user1}" : "Jūs dalyvavote skambutyje su {user1}",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečias"],
    "You attended a call with {user1} and {user2}" : "Jūs dalyvavote skambutyje su {user1} ir {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Jūs dalyvavote skambutyje su {user1}, {user2} ir {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Jūs dalyvavote skambutyje su {user1}, {user2}, {user3} ir {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Jūs dalyvavote skambutyje su {user1}, {user2}, {user3}, {user4} ir {user5}",
    "_%n other_::_%n others_" : ["dar %n asmuo","dar %n asmenys","dar %n asmenų","dar %n asmuo"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Jūs buvote pakviesti į <strong>pokalbį</strong> arba jums <strong>skambino</strong>",
    "Talk" : "Pokalbiai",
    "Guest" : "Svečias",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Sveiki atvykę į Nextcloud Pokalbius!\nŠiame pokalbyje būsite informuojami apie naujas Nextcloud Pokalbiuose prieinamas ypatybes.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Dabar, dalyvavimui vaizdo ir garso skambučiuose gali būti naudojamos Microsoft Edge ir Safari naršyklės",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Galite siųsti pranešimą visiems dalyviams, pokalbyje parašę \"@all\"",
    "- With the \"arrow-up\" key you can repost your last message" : "- Naudodami klavišą \"rodyklė aukštyn\" galite iš naujo paskelbti savo paskutinę žinutę",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Nuo šiol, Pokalbiuose gali būti komandos. Siųskite pokalbyje žinutę \"/help\" norėdami pamatyti ar jūsų administratorius yra sukonfigūravęs kokias nors komandas",
    "- With projects you can create quick links between conversations, files and other items" : "- Naudodami projektus galite greitai sukurti sąsajas tarp pokalbių, failų bei kitų elementų",
    "- You can now mention guests in the chat" : "- Dabar, pokalbiuose galite minėti svečius",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Dabar, galite tiesiogiai atsakyti į žinutes, suteikdami kitiems naudotojams daugiau konteksto apie ką yra jūsų žinutė",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas naudotojų grupes",
    "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
    "The command does not exist" : "Komandos nėra",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Vykdant komandą, įvyko klaida. Paprašykite administratoriaus, kad patikrintų žurnalus.",
    "Talk updates ✅" : "Pokalbių programėlės atnaujinimai ✅",
    "{actor} created the conversation" : "{actor} sukūrė pokalbį",
    "You created the conversation" : "Jūs sukūrėte pokalbį",
    "An administrator created the conversation" : "Administratorius sukūrė pokalbį",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "{actor} set the description" : "{actor} nustatė aprašą",
    "You set the description" : "Jūs nustatėte aprašą",
    "An administrator set the description" : "Administratorius nustatė aprašą",
    "{actor} removed the description" : "{actor} pašalino aprašą",
    "You removed the description" : "Jūs pašalinote aprašą",
    "An administrator removed the description" : "Administratorius pašalino aprašą",
    "{actor} started a call" : "{actor} pradėjo skambutį",
    "You started a call" : "Jūs pradėjote skambutį",
    "{actor} joined the call" : "{actor} prisijungė prie skambučio",
    "You joined the call" : "Jūs prisijungėte prie skambučio",
    "{actor} left the call" : "{actor} išėjo iš skambučio",
    "You left the call" : "Jūs išėjote iš skambučio",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Jūs atrakinote pokalbį",
    "An administrator unlocked the conversation" : "Administratorius atrakino pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "An administrator locked the conversation" : "Administratorius užrakino pokalbį",
    "The conversation is now open to everyone" : "Dabar, pokalbis yra atviras visiems",
    "{actor} opened the conversation to everyone" : "{actor} atvėrė pokalbį visiems",
    "You opened the conversation to everyone" : "Jūs atvėrėte pokalbį visiems",
    "{actor} restricted the conversation to moderators" : "{actor} apribojo pokalbį iki moderatorių",
    "You restricted the conversation to moderators" : "Jūs apribojote pokalbį iki moderatorių",
    "{actor} allowed guests" : "{actor} leidžia svečius",
    "You allowed guests" : "Jūs leidote svečius",
    "{actor} disallowed guests" : "{actor} nebeleidžia svečių",
    "You disallowed guests" : "Jūs nebeleidžiate svečių",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "An administrator set a password" : "Administratorius nustatė slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "An administrator removed the password" : "Administratorius pašalino slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You joined the conversation" : "Jūs prisijungėte prie pokalbio",
    "{actor} joined the conversation" : "{actor} prisijungė prie pokalbio",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "An administrator added {user}" : "Administratorius pridėjo naudotoją {user}",
    "You left the conversation" : "Jūs išėjote iš pokalbio",
    "{actor} left the conversation" : "{actor} išėjo iš pokalbio",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "An administrator removed {user}" : "Administratorius pašalino naudotoją {user}",
    "{actor} promoted {user} to moderator" : "{actor} paaukštino naudotoją {user} į moderatorius",
    "You promoted {user} to moderator" : "Jūs paaukštinote naudotoją {user} į moderatorius",
    "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
    "An administrator promoted you to moderator" : "Administratorius paaukštino jus į moderatorius",
    "An administrator promoted {user} to moderator" : "Administratorius paaukštino naudotoją {user} į moderatorius",
    "{actor} demoted {user} from moderator" : "{actor} pažemino naudotoją {user} iš moderatorių",
    "You demoted {user} from moderator" : "Jūs pažeminote naudotoją {user} iš moderatorių",
    "{actor} demoted you from moderator" : "{actor} pažemino jus iš moderatorių",
    "An administrator demoted you from moderator" : "Administratorius pažemino jus iš moderatorių",
    "An administrator demoted {user} from moderator" : "Administratorius pažemino naudotoją {user} iš moderatorių",
    "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
    "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
    "{actor} deleted a message" : "{actor} ištrynė žinutę",
    "You deleted a message" : "Jūs ištrynėte žinutę",
    "{actor} cleared the history of the conversation" : "{actor} išvalė pokalbio istoriją",
    "You cleared the history of the conversation" : "Jūs išvalėte pokalbio istoriją",
    "%s (guest)" : "%s (svečias)",
    "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Skambutis su {user1} ir {user2} (Trukmė {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Skambutis su {user1}, {user2} ir {user3} (Trukmė {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3} ir {user4} (Trukmė {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} (Trukmė {duration})",
    "Talk to %s" : "Kalbėti su %s",
    "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
    "No account available to delete." : "Nėra ištrynimui prieinamos paskyros.",
    "File is too big" : "Failas yra per didelis",
    "Invalid file provided" : "Pateiktas neteisingas failas",
    "Invalid image" : "Netinkamas paveikslas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
    "Talk mentions" : "Paminėjimai pokalbiuose",
    "Write to conversation" : "Rašyti į pokalbį",
    "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "Conversation invitation" : "Pakvietimas į pokalbį",
    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
    "Join »%s«" : "Prisijungti prie »%s«",
    "Meeting ID" : "Susitikimo ID",
    "Your PIN" : "Jūsų PIN kodas",
    "Password request: %s" : "Slaptažodžio prašymas: %s",
    "Private conversation" : "Privatus pokalbis",
    "Deleted user (%s)" : "Ištrintas naudotojas (%s)",
    "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
    "{user} sent a message in conversation {call}" : "{user} išsiuntė žinutę pokalbyje {call}",
    "A deleted user sent a message in conversation {call}" : "Ištrintas naudotojas išsiuntė žinutę pokalbyje {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (svečias) išsiuntė žinutę pokalbyje {call}",
    "A guest sent a message in conversation {call}" : "Svečias išsiuntė žinutę pokalbyje {call}",
    "{user} replied to your private message" : "{user} atsakė į jūsų privačią žinutę",
    "{user} replied to your message in conversation {call}" : "{user} atsakė į jūsų žinutę pokalbyje {call}",
    "A deleted user replied to your message in conversation {call}" : "Ištrintas naudotojas atsakė į jūsų žinutę pokalbyje {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (svečias) atsakė į jūsų žinutę pokalbyje {call}",
    "A guest replied to your message in conversation {call}" : "Svečias atsakė į jūsų žinutę pokalbyje {call}",
    "{user} mentioned you in a private conversation" : "{user} paminėjo jus privačiame pokalbyje",
    "{user} mentioned you in conversation {call}" : "{user} paminėjo jus pokalbyje {call}",
    "A deleted user mentioned you in conversation {call}" : "Ištrintas naudotojas paminėjo jus pokalbyje {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (svečias) paminėjo jus pokalbyje {call}",
    "A guest mentioned you in conversation {call}" : "Svečias paminėjo jus pokalbyje {call}",
    "View chat" : "Rodyti pokalbį",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "Join call" : "Prisijungti prie skambučio",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "Answer call" : "Atsiliepti",
    "{user} would like to talk with you" : "{user} norėtų su jumis pakalbėti",
    "Call back" : "Atskambinti",
    "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
    "You missed a group call in {call}" : "Jūs praleidote grupės skambutį ties {call}",
    "{email} is requesting the password to access {file}" : "{email} prašo slaptažodžio, kad gautų prieigą prie {file}",
    "{email} tried to request the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
    "Someone is requesting the password to access {file}" : "Kažkas prašo slaptažodžio, kad gautų prieigą prie {file}",
    "Someone tried to request the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
    "Open settings" : "Atverti nustatymus",
    "Conversations" : "Pokalbiai",
    "Messages" : "Žinutės",
    "{user}" : "{user}",
    "Something unexpected happened." : "Nutiko kažkas netikėto.",
    "The URL is invalid." : "URL yra neteisingas.",
    "An HTTPS URL is required." : "Reikalingas HTTPS URL.",
    "The email address is invalid." : "El. pašto adresas yra neteisingas.",
    "The language is invalid." : "Neteisinga kalba.",
    "The country is invalid." : "Neteisinga šalis.",
    "Something unexpected happened. Please try again later." : "Nutiko kažkas netikėto. Vėliau bandykite dar kartą.",
    "There is no such account registered." : "Nėra tokios registruotos paskyros.",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
    "Afghanistan" : "Afganistanas",
    "Antigua and Barbuda" : "Antigva ir Barbuda",
    "Anguilla" : "Angilija",
    "Albania" : "Albanija",
    "Armenia" : "Armėnija",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Azerbaijan" : "Azerbaidžanas",
    "Bosnia and Herzegovina" : "Bosnija ir Hercegovina",
    "Barbados" : "Barbadosas",
    "Bangladesh" : "Bangladešas",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Fasas",
    "Bulgaria" : "Bulgarija",
    "Bahrain" : "Bahreinas",
    "Burundi" : "Burundis",
    "Benin" : "Beninas",
    "Bermuda" : "Bermudai",
    "Brunei Darussalam" : "Brunėjaus Darusalamas",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahamos",
    "Bhutan" : "Butanas",
    "Botswana" : "Botsvana",
    "Belarus" : "Baltarusija",
    "Belize" : "Belizas",
    "Canada" : "Kanada",
    "Central African Republic" : "Centrinės Afrikos Respublika",
    "Congo" : "Kongas",
    "Switzerland" : "Šveicarija",
    "Chile" : "Čilė",
    "Cameroon" : "Kamerūnas",
    "China" : "Kinija",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Kuba",
    "Christmas Island" : "Kalėdų sala",
    "Cyprus" : "Kipras",
    "Czechia" : "Čekija",
    "Germany" : "Vokietija",
    "Djibouti" : "Džibutis",
    "Denmark" : "Danija",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikos Respublika",
    "Algeria" : "Alžyras",
    "Ecuador" : "Ekvadoras",
    "Estonia" : "Estija",
    "Egypt" : "Egiptas",
    "Eritrea" : "Eritrėja",
    "Spain" : "Ispanija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Suomija",
    "Fiji" : "Fidžis",
    "Falkland Islands (Malvinas)" : "Folklando (Malvinų) salos",
    "Faroe Islands" : "Farerų salos",
    "France" : "Prancūzija",
    "Gabon" : "Gabonas",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltaras",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvinėja",
    "Equatorial Guinea" : "Pusiaujo Gvinėja",
    "Greece" : "Graikija",
    "Guatemala" : "Gvatemala",
    "Guinea-Bissau" : "Bisau Gvinėja",
    "Guyana" : "Gajana",
    "Hong Kong" : "Honkongas",
    "Honduras" : "Hondūras",
    "Croatia" : "Kroatija",
    "Haiti" : "Haitis",
    "Hungary" : "Vengrija",
    "Indonesia" : "Indonezija",
    "Ireland" : "Airija",
    "Israel" : "Izraelis",
    "India" : "Indija",
    "Iraq" : "Irakas",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanija",
    "Japan" : "Japonija",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizija",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribatis",
    "Saint Kitts and Nevis" : "Sent Kitsas ir Nevis",
    "Kuwait" : "Kuveitas",
    "Kazakhstan" : "Kazachstanas",
    "Lebanon" : "Libanas",
    "Liechtenstein" : "Lichtenšteinas",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesotas",
    "Lithuania" : "Lietuva",
    "Luxembourg" : "Liuksemburgas",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Marokas",
    "Monaco" : "Monakas",
    "Montenegro" : "Juodkalnija",
    "Madagascar" : "Madagaskaras",
    "Marshall Islands" : "Maršalo salos",
    "Mali" : "Malis",
    "Myanmar" : "Mianmaras",
    "Mongolia" : "Mongolija",
    "Mauritania" : "Mauritanija",
    "Malta" : "Malta",
    "Mauritius" : "Mauricijus",
    "Maldives" : "Maldyvai",
    "Malawi" : "Malavis",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambikas",
    "Namibia" : "Namibija",
    "New Caledonia" : "Naujoji Kaledonija",
    "Niger" : "Nigeris",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nyderlandai",
    "Norway" : "Norvegija",
    "Nepal" : "Nepalas",
    "Nauru" : "Nauru",
    "New Zealand" : "Naujoji Zelandija",
    "Oman" : "Omanas",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Naujoji Gvinėja",
    "Philippines" : "Filipinai",
    "Pakistan" : "Pakistanas",
    "Poland" : "Lenkija",
    "Pitcairn" : "Pitkerno salos",
    "Puerto Rico" : "Puerto Rikas",
    "Portugal" : "Portugalija",
    "Paraguay" : "Paragvajus",
    "Qatar" : "Kataras",
    "Romania" : "Rumunija",
    "Serbia" : "Serbija",
    "Russian Federation" : "Rusijos Federacija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudo Arabija",
    "Solomon Islands" : "Saliamono salos",
    "Seychelles" : "Seišelių salos",
    "Sudan" : "Sudanas",
    "Sweden" : "Švedija",
    "Singapore" : "Singapūras",
    "Slovenia" : "Slovėnija",
    "Slovakia" : "Slovakija",
    "Sierra Leone" : "Siera Leonė",
    "Senegal" : "Senegalas",
    "Somalia" : "Somalis",
    "Suriname" : "Surinamas",
    "South Sudan" : "Pietų Sudanas",
    "El Salvador" : "Salvadoras",
    "Syrian Arab Republic" : "Sirijos Arabų Respublika",
    "Turks and Caicos Islands" : "Terkso ir Kaikoso salos",
    "Chad" : "Čadas",
    "Togo" : "Togas",
    "Thailand" : "Tailandas",
    "Tajikistan" : "Tadžikistanas",
    "Timor-Leste" : "Rytų Timoras",
    "Turkmenistan" : "Turkmėnistanas",
    "Tunisia" : "Tunisas",
    "Tonga" : "Tongų",
    "Turkey" : "Turkija",
    "Trinidad and Tobago" : "Trinidadas ir Tobagas",
    "Tanzania, United Republic of" : "Tanzanijos Jungtinė Respublika",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Jungtinių Valstijų nuošalios mažosios salos",
    "United States of America" : "Jungtinės Amerikos Valstijos",
    "Uruguay" : "Urugvajus",
    "Uzbekistan" : "Uzbekistanas",
    "Viet Nam" : "Vietnamas",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemenas",
    "South Africa" : "Pietų Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabvė",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
    "Conversation not found" : "Pokalbis nerastas",
    "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
    "Chat, video & audio-conferencing using WebRTC" : "Pokalbiai, vaizdo ir garso konferencijos naudojant WebRTC",
    "Leave call" : "Išeiti iš skambučio",
    "Stay in call" : "Pasilikti skambutyje",
    "Discuss this file" : "Aptarkite šį failą",
    "Share this file with others to discuss it" : "Bendrinti šį failą su kitais, norint jį aptarti",
    "Share this file" : "Bendrinti šį failą",
    "Join conversation" : "Prisijungti prie pokalbio",
    "Request password" : "Prašyti slaptažodžio",
    "Error requesting the password." : "Klaida prašant slaptažodžio.",
    "This conversation has ended" : "Šis pokalbis pasibaigė",
    "Limit to groups" : "Apriboti iki grupių",
    "Guests can still join public conversations." : "Svečiai vis tiek gali prisijungti prie viešų pokalbių.",
    "When a call has started, everyone with access to the conversation can join the call." : "Prasidėjus skambučiui, visi, turintys prieigą prie pokalbio, gali prisijungti prie skambučio.",
    "Everyone" : "Visi",
    "Users and moderators" : "Naudotojai ir moderatoriai",
    "Moderators only" : "Tik moderatoriai",
    "Save changes" : "Įrašyti pakeitimus",
    "Saving …" : "Įrašoma …",
    "Saved!" : "Įrašyta!",
    "None" : "Nėra",
    "User" : "Naudotojas",
    "Disabled" : "Išjungta",
    "Moderators" : "Moderatoriai",
    "Users" : "Naudotojai",
    "Commands" : "Komandos",
    "Beta" : "Beta",
    "Name" : "Vardas",
    "Command" : "Komanda",
    "Script" : "Scenarijus",
    "General settings" : "Bendri nustatymai",
    "Integration into other apps" : "Integracija į kitas programėles",
    "Allow conversations on files" : "Leisti pokalbius failuose",
    "Allow conversations on public shares for files" : "Leisti pokalbius viešai bendrinamuose failuose",
    "All messages" : "Visos žinutės",
    "@-mentions only" : "Tik @ paminėjimai",
    "Off" : "Išjungta",
    "URL of this Nextcloud instance" : "Šio Nextcloud egzemplioriaus URL",
    "Email of the user" : "Naudotojo el. paštas",
    "Language" : "Kalba",
    "Country" : "Šalis",
    "Status" : "Būsena",
    "Created at" : "Sukurta",
    "Expires at" : "Baigia galioti",
    "Pending" : "Laukiantis",
    "Error" : "Klaida",
    "Blocked" : "Blokuota",
    "Active" : "Aktyvi",
    "Expired" : "Nebegalioja",
    "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
    "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
    "Matterbridge integration" : "„Matterbridge“ integracija",
    "Enable Matterbridge integration" : "Įjungti „Matterbridge“ integraciją",
    "Downloading …" : "Atsisiunčiama…",
    "Installed version: {version}" : "Įdiegta versija: {version}",
    "SIP configuration" : "SIP konfigūracija",
    "Phone number (Country)" : "Telefono numeris (Šalis)",
    "Delete this server" : "Ištrinti šį serverį",
    "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
    "Error: Cannot connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
    "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
    "Saved" : "Įrašyta",
    "Add a new server" : "Pridėti naują serverį",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai turėtų būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Turėkite omenyje, kad skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio, dalyviai gali patirti ryšio problemas ir sukelti didelę apkrovą dalyvaujantiems įrenginiams.",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "Neįspėti apie jungiamumo problemas skambučiuose su daugiau kaip 4 dalyviais",
    "STUN server URL" : "STUN serverio URL",
    "STUN servers" : "STUN serveriai",
    "TURN server URL" : "TURN serverio URL",
    "TURN server secret" : "TURN serverio paslaptis",
    "TURN server protocols" : "TURN serverio protokolai",
    "Test this server" : "Išbandyti šį serverį",
    "TURN servers" : "TURN serveriai",
    "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
    "A participant raised their hand." : "Dalyvis pakėlė ranką.",
    "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapis",
    "Next page of videos" : "Kitas vaizdo įrašų puslapis",
    "Copy link" : "Kopijuoti nuorodą",
    "Connecting …" : "Jungiamasi…",
    "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
    "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "Conversation link copied to clipboard." : "Pokalbio nuoroda nukopijuota į iškarpinę.",
    "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Lower hand (R)" : "Nuleisti ranką (R)",
    "More actions" : "Daugiau veiksmų",
    "Settings" : "Nustatymai",
    "Dismiss" : "Atmesti",
    "Raise hand (R)" : "Pakelti ranką (R)",
    "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
    "No audio" : "Nėra jokio garso",
    "Mute audio (M)" : "Nutildyti garsą (M)",
    "Unmute audio (M)" : "Įjungti garsą (M)",
    "Mute audio" : "Nutildyti garsą",
    "Unmute audio" : "Įjungti garsą",
    "You are not allowed to enable video" : "Jums neleidžiama įjungti vaizdą",
    "No camera" : "Nėra kameros",
    "Disable video (V)" : "Išjungti vaizdą (V)",
    "Enable video (V)" : "Įjungti vaizdą (V)",
    "Disable video" : "Išjungti vaizdą",
    "Enable video" : "Įjungti vaizdą",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "Disable screenshare" : "Išjungti ekrano bendrinimą",
    "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Back" : "Atgal",
    "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
    "Error while accessing camera: it is likely in use by another program" : "Klaida gaunant prieigą prie kameros: tikėtina, kad ją naudoja kita programa",
    "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
    "You" : "Jūs",
    "Show screen" : "Rodyti ekraną",
    "Mute" : "Nutildyti",
    "This conversation is read-only" : "Šis pokalbis yra tik skaitymui",
    "Favorite" : "Mėgstamas",
    "Conversation settings" : "Pokalbio nustatymai",
    "Description" : "Aprašas",
    "Chat notifications" : "Pokalbio pranešimai",
    "Meeting settings" : "Susitikimo nustatymai",
    "Danger zone" : "Pavojinga zona",
    "Error while updating conversation description" : "Klaida atnaujinant pokalbio aprašą",
    "Be careful, these actions cannot be undone." : "Būkite atsargūs, šių veiksmų nebegalėsite atšaukti.",
    "Leave conversation" : "Išeiti iš pokalbio",
    "Delete conversation" : "Ištrinti pokalbį",
    "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
    "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
    "Error while deleting conversation" : "Klaida ištrinant pokalbį",
    "Password protection" : "Apsauga slaptažodžiu",
    "Enter a password" : "Enter a password",
    "Save password" : "Įrašyti slaptažodį",
    "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
    "Invitations sent" : "Pakvietimai išsiųsti",
    "Enable lobby" : "Įjungti laukimo salę",
    "Start time (optional)" : "Pradžios laikas (nebūtinas)",
    "Lock conversation" : "Užrakinti pokalbį",
    "Error occurred when locking the conversation" : "Užrakinant pokalbį, įvyko klaida",
    "Error occurred when unlocking the conversation" : "Atrakinant pokalbį, įvyko klaida",
    "Save" : "Įrašyti",
    "Edit" : "Taisyti",
    "More information" : "Daugiau informacijos",
    "Delete" : "Ištrinti",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud naudotojas",
    "User password" : "Naudotojo slaptažodis",
    "Matrix server URL" : "Matrix serverio URL",
    "Matrix channel" : "Matrix kanalas",
    "Team name" : "Komandos pavadinimas",
    "Channel name" : "Kanalo pavadinimas",
    "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
    "User name or email address" : "Naudotojo vardas ar el. pašto adresas",
    "Password" : "Slaptažodis",
    "Rocket.Chat channel" : "Rocket.Chat kanalas",
    "API token" : "API prieigos raktas",
    "Slack channel" : "Slack kanalas",
    "Server ID or name" : "Serverio ID ar pavadinimas",
    "Channel ID or name" : "Kanalo ID ar pavadinimas",
    "Channel" : "Kanalas",
    "Login" : "Prisijungti",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC serverio URL (pvz., chat.freenode.net:6667)",
    "Nickname" : "Slapyvardis",
    "IRC channel" : "IRC kanalas",
    "Use TLS" : "Naudoti TLS",
    "Use SASL" : "Naudoti SASL",
    "Client ID" : "Kliento ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber serverio URL",
    "MUC server URL" : "MUC serverio URL",
    "Jabber ID" : "Jabber ID",
    "unknown state" : "nežinoma būsena",
    "Mark as read" : "Žymėti kaip skaitytą",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "You: {lastMessage}" : "Jūs: {lastMessage}",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Open conversations" : "Atverti pokalbius",
    "Loading" : "Įkeliama",
    "No search results" : "Nėra paieškos rezultatų",
    "Groups" : "Grupės",
    "Circles" : "Ratai",
    "Talk settings" : "Pokalbių nustatymai",
    "Users, groups and circles" : "Naudotojai, grupės ir ratai",
    "Users and groups" : "Naudotojai ir grupės",
    "Users and circles" : "Naudotojai ir ratai",
    "Groups and circles" : "Grupės ir ratai",
    "Other sources" : "Kiti šaltiniai",
    "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
    "Creating your conversation" : "Kuriamas jūsų pokalbis",
    "All set" : "Viskas paruošta",
    "Error while creating the conversation" : "Klaida kuriant pokalbį",
    "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
    "Create a new group conversation" : "Sukurti naują grupės pokalbį",
    "Password protect" : "Apsaugoti slaptažodžiu",
    "Create conversation" : "Sukurti pokalbį",
    "Add participants" : "Pridėti dalyvius",
    "Close" : "Užverti",
    "Search participants" : "Ieškoti dalyvių",
    "Conversation name" : "Pokalbio pavadinimas",
    "Allow guests to join via link" : "Leisti svečiams prisijungti per nuorodą",
    "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
    "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
    "Calls are not supported in your browser" : "Jūsų naršyklėje skambučiai yra nepalaikomi",
    "Access to microphone is only possible with HTTPS" : "Prieiga prie mikrofono yra įmanoma tik naudojant HTTPS",
    "Access to microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
    "Error while accessing microphone" : "Klaida gaunant prieigą prie mikrofono",
    "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
    "Microphone" : "Mikrofonas",
    "Camera" : "Kamera",
    "No microphone available" : "Nėra prieinamo mikrofono",
    "Select microphone" : "Pasirinkti mikrofoną",
    "No camera available" : "Nėra prieinamos kameros",
    "Select camera" : "Pasirinkti kamerą",
    "Reply" : "Atsakyti",
    "Reply privately" : "Atsakyti privačiai",
    "Copy message link" : "Kopijuoti žinutės nuorodą",
    "Mark as unread" : "Žymėti kaip neskaitytą",
    "Go to file" : "Pereiti į failą",
    "Forward message" : "Persiųsti žinutę",
    "Unread messages" : "Neskaitytos žinutės",
    "Message sent" : "Žinutė išsiųsta",
    "You are not allowed to share files" : "Jums neleidžiama bendrinti failų",
    "You cannot send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį",
    "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
    "Remove {fileName}" : "Šalinti {fileName}",
    "Error while forwarding message" : "Klaida persiunčiant žinutę",
    "Scroll to bottom" : "Slinkti į apačią",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Microphone either not available or disabled in settings" : "Mikrofonas arba neprieinamas, arba išjungtas nustatymuose",
    "Share from Files" : "Bendrinti iš Failų",
    "Add emoji" : "Pridėti šypsenėlę",
    "Send message" : "Siųsti žinutę",
    "File to share" : "Failas, kurį bendrinti",
    "This conversation has been locked" : "Šis pokalbis užrakintas",
    "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Disable lobby" : "Išjungti laukimo salę",
    "moderator" : "moderatorius",
    "guest" : "svečias",
    "Demote from moderator" : "Pažeminti iš moderatorių",
    "Promote to moderator" : "Paaukštinti į moderatorius",
    "Resend invitation" : "Siųsti pakvietimą iš naujo",
    "Remove participant" : "Šalinti dalyvį",
    "Add groups" : "Pridėti grupes",
    "Add emails" : "Pridėti el. paštus",
    "Add circles" : "Pridėti ratus",
    "Searching …" : "Ieškoma…",
    "No results" : "Rezultatų nėra",
    "Search for more users" : "Ieškoti daugiau naudotojų",
    "Add users or groups" : "Pridėti naudotojus ar grupes",
    "Add groups or circles" : "Pridėti grupes ar ratus",
    "Add other sources" : "Pridėti kitus šaltinius",
    "Participants" : "Dalyviai",
    "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
    "Chat" : "Pokalbis",
    "Details" : "Išsamiau",
    "Meeting ID: {meetingId}" : "Susitikimo ID: {meetingId}",
    "Your PIN: {attendeePin}" : "Jūsų PIN kodas: {attendeePin}",
    "Display name: " : "Rodomas vardas: ",
    "Choose devices" : "Pasirinkti įrenginius",
    "Attachments folder" : "Priedų aplankas",
    "Privacy" : "Privatumas",
    "Sounds" : "Garsai",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Search" : "Ieškoti",
    "Space bar" : "Tarpas",
    "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
    "Start call" : "Pradėti skambutį",
    "Toggle fullscreen" : "Perjungti visą ekraną",
    "Rename conversation" : "Pervadinti pokalbį",
    "Exit fullscreen (F)" : "Išeiti iš viso ekrano (F)",
    "Fullscreen (F)" : "Visas ekranas (F)",
    "Grid view" : "Tinklelio rodinys",
    "Send" : "Siųsti",
    "Add more files" : "Pridėti daugiau failų",
    "No unread mentions" : "Nėra neskaitytų paminėjimų",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "Start a conversation" : "Pradėti pokalbį",
    "Message without mention" : "Rašyti be paminėjimo",
    "Mention myself" : "Paminėti save",
    "Mention room" : "Paminėti kambarį",
    "The conversation does not exist" : "Pokalbio nėra",
    "Join a conversation or start a new one!" : "Prisijunkite prie pokalbio arba pradėkite naują!",
    "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
    "Do not disturb" : "Netrukdyti",
    "Away" : "Atsitraukęs",
    "Error while sharing file" : "Klaida bendrinant failą",
    "Failed to join the conversation. Try to reload the page." : "Nepavyko prisijungti prie pokalbio. Pabandykite įkelti puslapį iš naujo.",
    "Leave this page" : "Išeiti iš šio puslapio",
    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
    "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
    "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
    "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…",
    "Default" : "Numatytoji",
    "Microphone {number}" : "Mikrofonas {number}",
    "Camera {number}" : "Kamera {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Atrodo, kad kalbate su išjungtu mikrofonu, įjunkite savo garsą, jei norite, kad kiti jus girdėtų",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tai užtrunka ilgiau, nei tikėtasi. Ar medijos leidimai jau yra suteikti (arba atmesti)? Jeigu taip, tuomet paleiskite savo naršyklę iš naujo, nes garsas ir vaizdas patiria nesėkmę",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo uždrausta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Error while accessing microphone & camera" : "Klaida gaunant prieigą prie mikrofono ir kameros",
    "This conversation is password-protected" : "Šis pokalbis yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "TURN server" : "TURN serveris",
    "Signaling servers" : "Signaliniai serveriai",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai gali būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
    "%s Talk on your mobile devices" : "%s Pokalbiai jūsų mobiliuosiuose įrenginiuose",
    "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "New in Talk 6" : "Kas naujo Pokalbiuose 6",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Dabar, pokalbiai vienu du yra išliekantys ir daugiau nebegali būti atsitiktinai paversti į grupės pokalbius. Be to, kai kuris nors vienas dalyvis išeina iš pokalbio, pokalbis daugiau nebėra automatiškai ištrinamas. Tik tuo atveju, jei abu dalyviai išėjo iš pokalbio, pokalbis yra ištrinamas iš serverio",
    "New in Talk 7" : "Kas naujo Pokalbiuose 7",
    "New in Talk 8" : "Nauja Pokalbiuose 8",
    "New in Talk 9" : "Nauja Pokalbiuose 9",
    "New in Talk 10" : "Nauja Pokalbiuose 10",
    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} nustatė „Matterbridge“, kad sinchronizuotų šį pokalbį su kitais pokalbiais.",
    "You set up Matterbridge to synchronize this conversation with other chats." : "Jūs nustatėte „Matterbridge“, kad sinchronizuotumėte šį pokalbį su kitais pokalbiais.",
    "{actor} updated the Matterbridge configuration." : "{actor} atnaujino „Matterbridge“ konfigūraciją.",
    "You updated the Matterbridge configuration." : "Jūs atnaujinote „Matterbridge“ konfigūraciją.",
    "{actor} removed the Matterbridge configuration." : "{actor} pašalino „Matterbridge“ konfigūraciją.",
    "You removed the Matterbridge configuration." : "Jūs pašalinote „Matterbridge“ konfigūraciją.",
    "{user} wants to talk with you" : "{user} nori su jumis pakalbėti",
    "E-mail of the user" : "Naudotojo el. paštas",
    "Error: Can not connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "Share whole screen" : "Bendrinti visą ekraną",
    "Share a single window" : "Bendrinti vieną langą",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "Unmute audio (m)" : "Įjungti garsą (m)",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (v) - Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
    "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
    "Remove" : "Šalinti",
    "[Unknown username]" : "[Nežinomas naudotojo vardas]",
    "Enabled" : "Įjungta",
    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
    "Participant settings" : "Dalyvio nustatymai",
    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
    "Share link" : "Bendrinimo nuoroda",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai nepalaiko pilnai jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
    "{actor} set the description to \"%1$s\"" : "{actor} nustatė aprašą į „%1$s“",
    "You set the description to \"%1$s\"" : "Jūs nustatėte aprašą į „%1$s“",
    "An administrator set the description to \"%1$s\"" : "Administratorius nustatė aprašą į „%1$s“",
    "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
    "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
    "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
    "Lower hand" : "Nuleisti ranką",
    "Raise hand" : "Pakelti ranką",
    "Conversation \"{conversationName}\"" : "Pokalbis „{conversationName}“",
    "You can not send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
